<!DOCTYPE html><html lang="en"><!-- Mirrored from html.kodesolution.com/2023/satnet-html/page-about.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:25 GMT --><head>
<meta charset="utf-8">
<title>Satnet | Broadband HTML Template</title>
<!-- Stylesheets -->
<link href="css/animate.css" rel="stylesheet">
<link href="css/bootstrap.min.css" rel="stylesheet">
<link href="css/slick.css" rel="stylesheet">
<link href="css/slick-theme.css" rel="stylesheet">
<link href="css/select2.min.css" rel="stylesheet">
<link href="css/swipebox.min.css" rel="stylesheet">
<link href="css/swiper-bundle.min.css" rel="stylesheet">
<link href="css/style.css" rel="stylesheet">

<link rel="shortcut icon" href="images/favicon2.png" type="image/x-icon">
<link rel="icon" href="images/favicon2.png" type="image/x-icon">

<!-- Responsive -->
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0">
<!--[if lt IE 9]><script src="https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.3/html5shiv.js"></script><![endif]-->
<!--[if lt IE 9]><script src="js/respond.js"></script><![endif]-->
<link rel="stylesheet" href="css/custom_elements.css?IyXJpCu8" id="custom-elements-css"><link rel="stylesheet" href="css/code_editor_styles.css?iNW0bFNc" id="custom-css"><link rel="stylesheet" href="font-awesome/font-awesome.min.css?WyX7LkLB" id="font-awesome"></head>

<body class="layout4">

<div class="page-wrapper">

	<!-- Preloader -->
	<div class="preloader"></div>

    <!-- Main Header-->
	<header class="main-header header-style-four inner-page-style">
		<!-- Header Top -->
		<div class="header-top">
			<div class="container">
				<div class="header-top-content">
					<div class="top-left">
						<!-- Info List -->
                        <ul class="info-list">
                            <li>
                                <i class="icon fa-solid fa-wifi"></i>
                                <span>Existing customer? View our exclusive offers for you</span>
                            </li>
                            <li>
                                <a href="#">log in</a>
                            </li>
                        </ul>
					</div>
					<ul class="social-links">
                        <li><span>Follow Us!</span></li>
                        <li><a href="#" title=""><i class="fab fa-facebook"></i></a></li>
                        <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                        <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                    </ul>
				</div>
			</div>
		</div>
		<!-- Header Top -->

        <div class="header-lower">
            <!-- Main box -->
            <div class="main-box">
                <div class="logo-box">
                    <div class="logo d-none d-lg-block"><a href="index.html"><img src="images/logo-v3-white.png" alt="" title="Satnet"></a></div>
                    <div class="logo d-block d-lg-none"><a href="index.html"><img src="images/logo-v4-black.png" alt="" title="Satnet"></a></div>
                </div>

                <!--Nav Box-->
                <div class="nav-outer">    
                    <nav class="nav main-menu">
                        <ul class="navigation">
                            <li class="current dropdown"><a href="index.html">Home</a>
                                <ul>
                                    <li><a href="index.html">Home page 01</a></li>
                                    <li><a href="index-2.html">Home page 02</a></li>
                                    <li><a href="index-3.html">Home page 03</a></li>
                                    <li><a href="index-4.html">Home page 04</a></li>
                                    <li class="dropdown"><a href="#">Single Styles</a>
                                        <ul>
                                            <li><a href="index-1-single.html">Single Style One</a></li>
                                            <li><a href="index-2-single.html">Single Style Two</a></li>
                                            <li><a href="index-3-single.html">Single Style Two</a></li>
                                            <li><a href="index-4-single.html">Single Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Dark Styles</a>
                                        <ul>
                                            <li><a href="index-1-dark.html">Darl Style One</a></li>
                                            <li><a href="index-2-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-3-dark.html">Darl Style Two</a></li>
                                            <li><a href="index-4-dark.html">Darl Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li class="dropdown"><a href="#">Header Styles</a>
                                        <ul>
                                            <li><a href="index.html">Header Style One</a></li>
                                            <li><a href="index-2.html">Header Style Two</a></li>
                                        </ul>
                                    </li>
                                    <li><a href="index-1-rtl.html">RTL Style One</a></li>
                                </ul>
                            </li>
                            <li class="dropdown"><a href="page-services.html">Services</a>
                                <ul>
                                    <li><a href="page-services.html">Services Grid</a></li>
                                    <li><a href="page-service-details.html">Service Details</a></li>
                                </ul>
                            </li>
							<li class="dropdown"><a href="page-about.html">Pages</a>
								<ul>
									<li><a href="page-about.html">About</a></li>
									<li><a href="page-movie.html">Movie</a></li>
									<li><a href="page-pricing.html">Pricing</a></li>
									<li class="dropdown"><a href="shop-products.html">Shop</a>
										<ul>
											<li><a href="shop-products.html">Products</a></li>
											<li><a href="shop-products-sidebar.html">Products Sidebar</a></li>
											<li><a href="shop-product-details.html">Product Details</a></li>
											<li><a href="shop-cart.html">Cart</a></li>
											<li><a href="shop-checkout.html">Checkout</a></li>
										</ul>
									</li>
									<li><a href="page-team.html">Team</a></li>
									<li><a href="page-testimonial.html">Testimonial</a></li>
									<li><a href="page-faq.html">FAQ</a></li>
									<li><a href="page-404.html">Page 404</a></li>
								</ul>
							</li>
							<li class="dropdown"><a href="news-grid.html">News</a>
								<ul>
									<li><a href="news-grid.html">News Grid</a></li>
									<li><a href="news-details.html">News Details</a></li>
								</ul>
							</li>
                            <li><a href="page-contact.html">Contact</a></li>
                        </ul>
                    </nav>
                    <!-- Main Menu End-->
                </div>

                <div class="outer-box">
                    <!-- Header Search -->
						<button class="search-btn">
                            <i class="flaticon-search"></i>
						</button>
						<button class="login-btn">
                            <i class="flaticon-user"></i>
						</button>
                    <a href="#" title="" class="header-btn">Get Connection</a>
                    <div class="mobile-nav-toggler"><span class="icon lnr-icon-bars"></span></div>
                    <!-- Mobile Nav toggler -->
                </div>
            </div>
        </div>
		
		<!-- Mobile Menu  -->
		<div class="mobile-menu">
			<div class="menu-backdrop"></div>
		
			<!--Here Menu Will Come Automatically Via Javascript / Same Menu as in Header-->
			<nav class="menu-box">
				<div class="upper-box">
					<div class="nav-logo"><a href="index.html"><img src="images/logo-v2-white.png" alt="" title=""></a></div>
					<div class="close-btn"><i class="icon fa fa-times"></i></div>
				</div>
		
				<ul class="navigation clearfix">
					<!--Keep This Empty / Menu will come through Javascript-->
				</ul>
				<ul class="contact-list-one">
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<i class="icon lnr-icon-phone-handset"></i>
							<span class="title">Call Now</span>
							<a href="tel:+92880098670">+92 (8800) - 98670</a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-envelope1"></span>
							<span class="title">Send Email</span>
							<a href="https://html.kodesolution.com/cdn-cgi/l/email-protection#ff979a938fbf9c90928f9e9186d19c9092"><span class="__cf_email__" data-cfemail="5d3538312d1d3e32302d3c3324733e3230">[email&nbsp;protected]</span></a>
						</div>
					</li>
					<li>
						<!-- Contact Info Box -->
						<div class="contact-info-box">
							<span class="icon lnr-icon-clock"></span>
							<span class="title">Send Email</span>
							Mon - Sat 8:00 - 6:30, Sunday - CLOSED
						</div>
					</li>
				</ul>
		
		
				<ul class="social-links">
					<li><a href="#"><i class="fa fa-x"></i></a></li>
					<li><a href="#"><i class="fab fa-facebook-f"></i></a></li>
					<li><a href="#"><i class="fab fa-pinterest"></i></a></li>
					<li><a href="#"><i class="fab fa-instagram"></i></a></li>
				</ul>
			</nav>
		</div><!-- End Mobile Menu -->

		<!-- Header Search -->
		<div class="search-popup">
			<span class="search-back-drop"></span>
			<button class="close-search"><span class="fa fa-times"></span></button>
		
			<div class="search-inner">
				<form method="post" action="https://html.kodesolution.com/2023/satnet-html/index.html">
					<div class="form-group">
						<input type="search" name="search-field" value="" placeholder="Search..." required="">
						<button type="submit"><i class="fa fa-search"></i></button>
					</div>
				</form>
			</div>
		</div>
		<!-- End Header Search -->

		<!-- Sticky Header  -->
		<div class="sticky-header">
			<div class="auto-container">
				<div class="inner-container">
					<!--Logo-->
					<div class="logo">
						<a href="index.html" title=""><img src="images/logo-v2-white.png" alt="" title=""></a>
					</div>
		
					<!--Right Col-->
					<div class="nav-outer">
						<!-- Main Menu -->
						<nav class="main-menu">
							<div class="navbar-collapse show collapse clearfix">
								<ul class="navigation clearfix">
									<!--Keep This Empty / Menu will come through Javascript-->
								</ul>
							</div>
						</nav><!-- Main Menu End-->
		
						<!--Mobile Navigation Toggler-->
						<div class="mobile-nav-toggler"><span class="icon lnr-icon-bars"></span></div>
					</div>
				</div>
			</div>
		</div><!-- End Sticky Menu -->
	</header>
	<!--End Main Header -->

	<!-- Start main-content -->
	<section class="page-title" style="background-image: url(images/background/page-title.jpg);">
		<div class="auto-container">
			<div class="title-outer">
				<ul class="page-breadcrumb">
					<li><a href="index.html">Home</a></li>
					<li>About</li>
				</ul>
				<h1 class="title">About Us</h1>
			</div>
		</div>
	</section>
	<!-- end main-content -->

    <!-- about section -->
    <section class="about-section-four">
        <div class="auto-container">
            <div class="sec-title-v4 text-center">
                <div class="icon-box wow fadeInUp"><i class="flaticon-wifi-1"></i></div>
                <h2 class="wow fadeInUp" data-wow-delay="100ms">Enter Your Postcode <br>to See What Speeds You Can Get</h2>
                <form class="wow fadeInUp" data-wow-delay="200ms">
                    <div class="input-area">
                        <div class="input-field">
                            <i class="icon fa fa-map-marker-alt"></i>
                            <input type="text" name="email" placeholder="Enter Your Postcode">
                            <select class="js-example-basic-single" name="state">
                                <option value="AL">I Am a Home User</option>
                                <option value="WY">I Am a Home User</option>
                            </select>
                        </div>
                        <button type="submit">Check Availability</button>
                    </div>
                </form>
            </div>
            <div class="row">
                <div class="content-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column wow fadeInLeft">
                        <span class="sub-title">SUSTAINABILITY IS OUR FOCUS</span>
                        <h2 class="title">We Provide Best Home <br>Network For You.</h2>
                        <p class="text">Lorem ipsum dolor sit amet, consectetur adipisicing elit,sed eius to 
                            incididunt ut labore et dolore magna aliqua. Ut enims ad minim veni
                            massa. Lorem ipsum dolor sit amet,to mod tempor incididunt</p>
                        <div class="row">
                            <div class="about-block-four col-lg-4 col-md-6 col-sm-12">
                                <div class="inner-box">
                                    <div class="icon-box">
                                        <i class="flaticon-services"></i>
                                        <h6 class="title">A Reliable <br>Connection</h6>
                                    </div>
                                </div>
                            </div>
                            <div class="about-block-four col-lg-4 col-md-6 col-sm-12">
                                <div class="inner-box">
                                    <div class="icon-box">
                                        <i class="flaticon-globe-grid"></i>
                                        <h6 class="title">Powerful Secure <br>Internet</h6>
                                    </div>
                                </div>
                            </div>
                            <div class="about-block-four col-lg-4 col-md-6 col-sm-12">
                                <div class="inner-box">
                                    <div class="icon-box">
                                        <i class="flaticon-streaming"></i>
                                        <h6 class="title">Flex 4K &amp; 8K <br>streaming</h6>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="image-column col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-column">
                        <div class="image-box">
                            <figure class="image-1 wow fadeInRight"><img src="images/resource/about4-7.png" alt=""></figure>
                            <figure class="image-2 wow zoomIn"><img src="images/resource/about4-8.png" alt=""></figure>
                            <figure class="image-3 wow zoomIn" data-wow-delay="300ms"><img src="images/resource/about4-9.png" alt=""></figure>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End about section -->

    <!-- deals section -->
    <section class="deals-section-v3">
        <div class="auto-container">
            <div class="sec-title-v4 text-center wow fadeInUp">
                <img src="images/resource/sec-img.png" alt="">
                <span class="sub-title">GUARANTEED SPEEDS AND A RELIABLE CONNECTION</span>
                <h2>Explore Our Deals</h2>
            </div>
            <div class="row">
                <div class="deals-block-v3 col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-box wow fadeInLeft">
                        <h6 class="title">Get TV Service with <br>Internet Service</h6>
                        <div class="social-list">
                            <div class="icon-box">
                                <div class="icon"><i class="flaticon-upload"></i></div>
                                <h6 class="title">1 Gbps Data</h6>
                            </div>
                            <div class="icon-box">
                                <div class="icon"><i class="flaticon-globe-grid"></i></div>
                                <h6 class="title">Wifi Seamless</h6>
                            </div>
                            <div class="icon-box">
                                <div class="icon"><i class="flaticon-tv-monitor"></i></div>
                                <h6 class="title">TV Internet</h6>
                            </div>
                        </div>
                        <div class="btn-box">
                            <a href="#" class="read-more">Check Availability</a>
                        </div>
                        <div class="image-box-v2">
                            <figure class="image"><img src="images/resource/deals3-4.png" alt=""></figure>
                        </div>
                    </div>
                </div>
                <div class="deals-block-v3 col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-box-v2 wow fadeInUp">
                        <div class="content-box">
                            <h6 class="title">Upto 25x Faster <br>Broadband</h6>
                            <p>offers a whole-family broadband <br>and mobile </p>
                            <a href="#" class="read-more"><i class="fa-solid fa-arrow-right"></i>Learn More</a>
                        </div>
                        <div class="image-box-v3">
                            <figure class="image"><img src="images/resource/deals3-5.png" alt=""></figure>
                        </div>
                    </div>
                    <div class="inner-box-v2 wow fadeInUp" data-wow-delay="200ms">
                        <div class="content-box">
                            <h6 class="title">Broadband + <br>Save on Mobile</h6>
                            <p>offers a whole-family broadband <br>and mobile </p>
                            <a href="#" class="read-more"><i class="fa-solid fa-arrow-right"></i>Learn More</a>
                        </div>
                        <div class="image-box-v3">
                            <figure class="image"><img src="images/resource/deals3-6.png" alt=""></figure>
                        </div>
                    </div>
                </div>
                <div class="deals-block-v3 col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-box-v4 wow fadeInLeft">
                        <h2 class="title">Award-Winning <br>Broadband You’ll Love</h2>
                        <p>let you know about all the awards we’ve won in 2023</p>
                    </div>
                </div>
                <div class="deals-block-v3 col-lg-6 col-md-12 col-sm-12">
                    <div class="inner-box-v4">
                        <div class="image-box">
                            <figure class="image wow fadeIn"><img src="images/resource/deals3-8.png" alt=""></figure>
                            <figure class="image wow fadeIn" data-wow-delay="200ms"><img src="images/resource/deals3-9.png" alt=""></figure>
                            <figure class="image wow fadeIn" data-wow-delay="300ms"><img src="images/resource/deals3-10.png" alt=""></figure>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End deals section -->

    <!-- services-section-three -->
    <section class="services-section-three">
        <div class="auto-container">
            <div class="sec-title-v4 text-center wow fadeInUp">
                <img src="images/resource/sec-img.png" alt="">
                <span class="sub-title">GUARANTEED SPEEDS AND A RELIABLE CONNECTION</span>
                <h2>Explore Our Services</h2>
            </div>
            <div class="row">
                <div class="service-block-three col-lg-3 col-md-6 col-sm-12">
                    <div class="inner-box">
                        <div class="icon-box"><i class="flaticon-wifi-router"></i></div>
                        <h4 class="title">Unlimited Broadband</h4>
                        <p>Lorem ipsum, or lipsum as it is some
                            times known, is dumm Lorem ipsum
                            or lipsum as it is some.</p>
                    </div>
                    <div class="inner-box">
                        <div class="icon-box"><i class="flaticon-router"></i></div>
                        <h4 class="title">Secure Internet</h4>
                        <p>Lorem ipsum, or lipsum as it is some
                            times known, is dumm Lorem ipsum
                            or lipsum as it is some.</p>
                    </div>
                </div>
                <div class="service-block-three col-lg-6 col-md-6 col-sm-12">
                    <div class="image-box wow zoomIn">
                        <figure class="image"><a href="#"><img src="images/resource/service4-3.png" alt=""></a></figure>
                        <a href="#" class="read-more">View All Services</a>
                    </div>
                </div>
                <div class="service-block-three col-lg-3 col-md-6 col-sm-12">
                    <div class="inner-box">
                        <div class="icon-box"><i class="flaticon-internet"></i></div>
                        <h4 class="title">Stronger Wi-Fi</h4>
                        <p>Lorem ipsum, or lipsum as it is some
                            times known, is dumm Lorem ipsum
                            or lipsum as it is some.</p>
                    </div>
                    <div class="inner-box">
                        <div class="icon-box"><i class="flaticon-speedometer"></i></div>
                        <h4 class="title">Great Speeds</h4>
                        <p>Lorem ipsum, or lipsum as it is some
                            times known, is dumm Lorem ipsum
                            or lipsum as it is some.</p>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End services-section-three -->

    <!-- main footer four -->
    <section class="footer-v4">
        <div class="footer-top">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-4 text-column">
                        <h4 class="title">Sign up for our <br>newsletter</h4>
                    </div>
                    <div class="col-lg-8 contact-info">
                        <div class="inner-box">
                            <p>Stay up to update with our latest news and products.</p>
                            <form>
                                <input type="text" name="email" placeholder="Enter your email address...">
                                <button type="submit">Subscribe</button>
                            </form>
                        </div>
                    </div><!--contact-info-->
                </div>
            </div>
        </div>
        <div class="container py-0">
            <div class="widgets-sections">
                <div class="footer-title text-center wow fadeInUp">
                    <img src="images/logo-v2.png" alt="">
                    <p>Our award-winning, experts customer support <br>is available 7 days a week</p>
                </div>
                <div class="contact-widget row align-items-center justify-content-center">
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInLeft">
                        <figure class="image"><img src="images/resource/phone.png" alt=""></figure>
                        <h6 class="title">+88(9800) 6802</h6>
                    </div>
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInUp" data-wow-delay="200ms">
                        <figure class="image"><img src="images/resource/phone-2.png" alt=""></figure>
                        <h6 class="title">Town 24/ United State</h6>
                    </div>
                    <div class="inner-box col-lg-3 col-md-4 col-sm-6 wow fadeInRight" data-wow-delay="300ms">
                        <figure class="image"><img src="images/resource/phone-3.png" alt=""></figure>
                        <h6 class="title"><a href="https://html.kodesolution.com/cdn-cgi/l/email-protection" class="__cf_email__" data-cfemail="beebcddbccd0dfd3dbfedad1d3dfd7d090ddd1d3">[email&nbsp;protected]</a></h6>
                    </div>
                </div>
            </div>
        </div>
        <div class="footer-bottom">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-md-4 copyright-text text-center text-lg-start">
                        <p>Copyright © reserved by . koresolution.</p>
                    </div>
                    <div class="col-md-4 social-column text-center">
                        <ul class="social-links">
                            <li><a href="#" title=""><i class="fab fa-facebook-square"></i></a></li>
                            <li><a href="#" title=""><i class="fab fa-google-plus-g"></i></a></li>
                            <li><a href="#" title=""><i class="fa fa-x"></i></a></li>
                        </ul>
                    </div>
                    <div class="col-md-4 links-column text-center text-lg-end">
                        <ul class="other-links">
                            <li><a href="#" title="">About</a></li>
                            <li><a href="#" title="">Terms</a></li>
                            <li><a href="#" title="">privacy policy</a></li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- End footer section -->

</div>
<!-- End Page Wrapper -->


<!-- Scroll To Top -->
<div class="scroll-to-top scroll-to-target" data-target="html"><span class="fa fa-angle-up"></span></div>


<script data-cfasync="false" src="../../cdn-cgi/scripts/5c5dd728/cloudflare-static/email-decode.min.js"></script><script src="js/jquery.js"></script>
<script src="js/popper.min.js"></script>
<script src="js/bootstrap.min.js"></script>
<script src="js/jquery.fancybox.js"></script>
<script src="js/jquery-ui.js"></script>
<script src="js/wow.js"></script>
<script src="js/appear.js"></script>
<script src="js/select2.min.js"></script>
<script src="js/script.js"></script>



<script id="custom-js" src="js/code_editor_scripts.js?tbpN9dRz"></script></body><!-- Mirrored from html.kodesolution.com/2023/satnet-html/page-about.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:15:25 GMT --></html>